/*
    DualWord-RT : https://github.com/dualword/dualword-rt

    Copyright (C) 2015-2025 Alexander Busorgin

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "View.h"

View::View(QWidget * p) : QGraphicsView(p) {

	setFocusPolicy(Qt::StrongFocus);
	setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
	setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
	setRenderHints(QPainter::Antialiasing);
	setCacheMode(QGraphicsView::CacheBackground);
	setDragMode(QGraphicsView::NoDrag);
	setMouseTracking(false);

}

View::~View() {

}

void View::resizeEvent (QResizeEvent *event){
	Q_UNUSED(event);
	this->fitInView(scene()->sceneRect(), Qt::KeepAspectRatio);
}
