/*
    DualWord-RT : https://github.com/dualword/dualword-rt

    Copyright (C) 2015-2025 Alexander Busorgin

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GLOBAL_H_
#define GLOBAL_H_


static const int RT_MAX = 1000; // upper limit (ms)
static const int RT_DMIN = 1; // delay lower limit (ms)
static const int RT_DMAX = 5; // delay upper limit (ms)
static constexpr int RT_TIMEOUT = RT_DMAX * 1000 + 1000;

struct dat {
    int left;
    int right;

};

#endif /* GLOBAL_H_ */
